==> neon_messagebus_mq_connector-0.2.1a0-py3-none-any.whl: neon_messagebus_mq_connector/__main__.py <==
# NEON AI (TM) SOFTWARE, Software Development Kit & Application Framework
# All trademark and other rights reserved by their respective owners
# Copyright 2008-2022 Neongecko.com Inc.
# Contributors: Daniel McKnight, Guy Daniels, Elon Gasper, Richard Leeds,
# Regina Bloomstine, Casimiro Ferreira, Andrii Pernatii, Kirill Hrymailo
# BSD-3 License
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
# 1. Redistributions of source code must retain the above copyright notice,
#    this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright notice,
#    this list of conditions and the following disclaimer in the documentation
#    and/or other materials provided with the distribution.
# 3. Neither the name of the copyright holder nor the names of its
#    contributors may be used to endorse or promote products derived from this
#    software without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
# THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR
# CONTRIBUTORS  BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA,
# OR PROFITS;  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
# LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
# NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE,  EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


import os
import sys

from typing import Optional
from neon_utils.logger import LOG

from neon_messagebus_mq_connector.config import Configuration
from neon_messagebus_mq_connector import ChatAPIProxy


def _get_default_config() -> dict:
    try:
        return Configuration(
            from_files=[os.environ.get('CHAT_API_PROXY_CONFIG',
                                       'config.json')]).config_data
    except Exception as e:
        LOG.error(e)
        return dict()


def main(config: Optional[dict] = None, daemon=False):
    config = config or _get_default_config()
    try:
        connector = ChatAPIProxy(config=config, service_name='chat_api_proxy')
        connector.run(run_sync=False, run_consumers=True,
                      daemonize_consumers=daemon)
    except Exception as ex:
        LOG.error(f'Chat API Proxy Listener (pid: {os.getpid()}) interrupted '
                  f'due to exception: {ex}')
        sys.exit(-1)


if __name__ == '__main__':
    LOG.info(f'Starting Chat API Proxy Listener (pid: {os.getpid()})...')
    main()

==> neon_messagebus_mq_connector-0.3.4a3-py3-none-any.whl: neon_messagebus_mq_connector/__main__.py <==
# NEON AI (TM) SOFTWARE, Software Development Kit & Application Framework
# All trademark and other rights reserved by their respective owners
# Copyright 2008-2022 Neongecko.com Inc.
# Contributors: Daniel McKnight, Guy Daniels, Elon Gasper, Richard Leeds,
# Regina Bloomstine, Casimiro Ferreira, Andrii Pernatii, Kirill Hrymailo
# BSD-3 License
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
# 1. Redistributions of source code must retain the above copyright notice,
#    this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright notice,
#    this list of conditions and the following disclaimer in the documentation
#    and/or other materials provided with the distribution.
# 3. Neither the name of the copyright holder nor the names of its
#    contributors may be used to endorse or promote products derived from this
#    software without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
# THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR
# CONTRIBUTORS  BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA,
# OR PROFITS;  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
# LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
# NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE,  EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


import os
import sys

from typing import Optional
from neon_utils.logger import LOG

from neon_messagebus_mq_connector.config import Configuration
from neon_messagebus_mq_connector import ChatAPIProxy


def _get_default_config() -> dict:
    try:
        return Configuration(
            from_files=[os.environ.get('CHAT_API_PROXY_CONFIG',
                                       'config.json')]).config_data
    except Exception as e:
        LOG.error(e)
        return dict()


def main(config: Optional[dict] = None, daemon=False):
    LOG.info(f'Starting Neon Message Bus Proxy Listener (pid: {os.getpid()})...')
    config = config or _get_default_config()
    try:
        connector = ChatAPIProxy(config=config, service_name='chat_api_proxy')
        connector.run(run_sync=True, run_consumers=True,
                      daemonize_consumers=daemon)
    except Exception as ex:
        LOG.error(f'Chat API Proxy Listener (pid: {os.getpid()}) interrupted '
                  f'due to exception: {ex}')
        sys.exit(-1)


if __name__ == '__main__':
    main()
